@@ -41,10 +41,6 @@ class showOSD(ranaModule):
 #                      'speed'
 #                      )
     
-  def update(self):
-    # Get and set functions are used to access global data
-    self.set('num_updates', self.get('num_updates', 0) + 1)
-    #print "Updated %d times" % (self.get('num_updates'))
 
   def drawScreenOverlay(self, cr):
     """ draw currenty active information widgets TODO: just draw object from list"""
